package WebGUI::i18n::English::Asset_Product;
use strict;

our $I18N = {
	'cache timeout' => {
		message => q|Cache Timeout|,
		lastUpdated => 0
		},

	'cache timeout help' => {
		message => q|Since all users will see this asset the same way, we can cache it for long periods of time to increase performance. How long should we cache it?|,
		lastUpdated => 0
		},

	'33' => {
		message => q|Related Products|,
		lastUpdated => 1031514049
	},

	'32' => {
		message => q|Accessories|,
		lastUpdated => 1031514049
	},

	'brochure_icon' => {
		message => q|The URL to the icon for the brochure.|,
		lastUpdated => 1211659018,
	},

	'brochure_url' => {
		message => q|The URL to download the brochure.|,
		lastUpdated => 1149655398,
	},

	'brochure_label' => {
		message => q|The translated label for the brochure URL.|,
		lastUpdated => 1149655398,
	},

	'manual_icon' => {
		message => q|The URL to the icon for the manual.|,
		lastUpdated => 1149655398,
	},

	'manual_url' => {
		message => q|The URL to download the manual.|,
		lastUpdated => 1149655398,
	},

	'manual_label' => {
		message => q|The translated label for the manual URL.|,
		lastUpdated => 1149655398,
	},

	'warranty_icon' => {
		message => q|The URL to the icon for the warranty.|,
		lastUpdated => 1149655398,
	},

	'warranty_url' => {
		message => q|The URL to download the warranty.|,
		lastUpdated => 1149655398,
	},

	'warranty_label' => {
		message => q|The label for the warranty URL.|,
		lastUpdated => 1149655398,
	},

	'image1' => {
		message => q|The URL to the first image uploaded to this product.|,
		lastUpdated => 1149655398,
	},

	'thumbnail1' => {
		message => q|The URL to the thumbnail of the first image uploaded to this product.|,
		lastUpdated => 1149655398,
	},

	'image2' => {
		message => q|The URL to the second image uploaded to this product.|,
		lastUpdated => 1149655398,
	},

	'thumbnail2' => {
		message => q|The URL to the thumbnail of the second image uploaded to this product.|,
		lastUpdated => 1149655398,
	},

	'image3' => {
		message => q|The URL to the third image uploaded to this product.|,
		lastUpdated => 1149655398,
	},

	'thumbnail3' => {
		message => q|The URL to the thumbnail of the third image uploaded to this product.|,
		lastUpdated => 1149655398,
	},

	'addfeature_url' => {
		message => q|The URL to add a feature to this product.|,
		lastUpdated => 1149655398,
	},

	'addfeature_label' => {
		message => q|The translated label for the add feature link.|,
		lastUpdated => 1149655398,
	},

	'feature_loop' => {
		message => q|This loop contains all of the features associated with this product.|,
		lastUpdated => 1149655398,
	},

	'feature_controls' => {
		message => q|The WebGUI management controls for this feature.|,
		lastUpdated => 1149655398,
	},

	'feature_feature' => {
		message => q|The text of the feature itself.|,
		lastUpdated => 1149655398,
	},

	'addbenefit_url' => {
		message => q|The URL to add a benefit to this product.|,
		lastUpdated => 1149655398,
	},

	'addbenefit_label' => {
		message => q|The translated label for the add benefit link.|,
		lastUpdated => 1149655398,
	},

	'benefit_loop' => {
		message => q|This loop contains the benefits for this product.|,
		lastUpdated => 1149655398,
	},

	'benefit_benefit' => {
		message => q|The benefit text itself.|,
		lastUpdated => 1149655398,
	},

	'benefit_controls' => {
		message => q|The WebGUI management controls for this benefit.|,
		lastUpdated => 1149655398,
	},

	'addspecification_url' => {
		message => q|The URL to add a specification to this product.|,
		lastUpdated => 1149655398,
	},

	'addspecification_label' => {
		message => q|The translated label for the add specification link.|,
		lastUpdated => 1149655398,
	},

	'specification_loop' => {
		message => q|The list of specifications associated with this product.|,
		lastUpdated => 1149655398,
	},

	'specification_controls' => {
		message => q|The WebGUI management controls for this specification.|,
		lastUpdated => 1149655398,
	},

	'specification_specification' => {
		message => q|The text of the specification itself.|,
		lastUpdated => 1149655398,
	},

	'specification_units' => {
		message => q|The units for this specification. ex: meters|,
		lastUpdated => 1149655398,
	},

	'specification_label' => {
		message => q|The label for this specification. ex: height|,
		lastUpdated => 1149655398,
	},

	'addaccessory_url' => {
		message => q|The URL to add an accessory to this product.|,
		lastUpdated => 1149655398,
	},

	'addaccessory_label' => {
		message => q|The translated label for the add accessory link.|,
		lastUpdated => 1149655398,
	},

	'accessory_loop' => {
		message => q|This loop contains all of the accessories associated with this product.|,
		lastUpdated => 1149655398,
	},

	'accessory_url' => {
		message => q|The URL to the linked accessory.|,
		lastUpdated => 1149655398,
	},

	'accessory_title' => {
		message => q|The title of the linked accessory.|,
		lastUpdated => 1149655398,
	},

	'accessory_controls' => {
		message => q|The WebGUI management controls for this accessory.|,
		lastUpdated => 1149655398,
	},

	'addRelatedProduct_url' => {
		message => q|The URL to add a related product to this product.|,
		lastUpdated => 1149655398,
	},

	'addRelatedProduct_label' => {
		message => q|The translated label for the add related product link.|,
		lastUpdated => 1149655398,
	},

	'relatedproduct_loop' => {
		message => q|This loop contains all of the products related to this product.|,
		lastUpdated => 1149655398,
	},

	'relatedproduct_url' => {
		message => q|The URL to the related product.|,
		lastUpdated => 1149655398,
	},

	'relatedproduct_title' => {
		message => q|The title of the related product.|,
		lastUpdated => 1149655398,
	},

	'relatedproduct_controls' => {
		message => q|The WebGUI management controls for this related product.|,
		lastUpdated => 1149655398,
	},

	'21' => {
		message => q|Add another related product?|,
		lastUpdated => 1031514049
	},

	'7' => {
		message => q|Product Image 1|,
		lastUpdated => 1031514049
	},

	'26' => {
		message => q|Label|,
		lastUpdated => 1031514049
	},

	'17' => {
		message => q|Accessory|,
		lastUpdated => 1031514049
	},

	'2' => {
		message => q|Are you certain you wish to delete the relationship to this accessory?|,
		lastUpdated => 1031514049
	},

	'assetName' => {
		message => q|Product|,
		lastUpdated => 1128831682
	},

	'18' => {
		message => q|Add another accessory?|,
		lastUpdated => 1031514049
	},

	'30' => {
		message => q|Features|,
		lastUpdated => 1031514049
	},

	'16' => {
		message => q|Add Accessory|,
		lastUpdated => 1031514049
	},

	'55' => {
		message => q|Add a benefit.|,
		lastUpdated => 1031514049
	},

	'27' => {
		message => q|Specification|,
		lastUpdated => 1031514049
	},

	'25' => {
		message => q|Edit Specification|,
		lastUpdated => 1031514049
	},

	'28' => {
		message => q|Add another specification?|,
		lastUpdated => 1031514049
	},

	'57' => {
		message => q|Are you certain you wish to delete this template and set all the products using it to the default template?|,
		lastUpdated => 1031514049
	},

	'20' => {
		message => q|Related Product|,
		lastUpdated => 1031514049
	},

	'14' => {
		message => q|Manual|,
		lastUpdated => 1031514049
	},

	'59' => {
		message => q|Name|,
		lastUpdated => 1031514049
	},

	'24' => {
		message => q|Add another feature?|,
		lastUpdated => 1031514049
	},

	'10' => {
		message => q|Price|,
		lastUpdated => 1031514049
	},

	'31' => {
		message => q|Specifications|,
		lastUpdated => 1031514049
	},

	'specs' => {
		message => q|Specs|,
		lastUpdated => 1211168475,
        context => q|Abbreviation of Specifications|,
	},

	'35' => {
		message => q|Add a specification.|,
		lastUpdated => 1031514049
	},

	'53' => {
		message => q|Edit Benefit|,
		lastUpdated => 1031514049
	},

	'48' => {
		message => q|Are you certain you wish to delete this benefit? It cannot be recovered once it has been deleted.|,
		lastUpdated => 1031514049
	},

	'22' => {
		message => q|Edit Feature|,
		lastUpdated => 1031514049
	},

	'13' => {
		message => q|Brochure|,
		lastUpdated => 1031514049
	},

	'23' => {
		message => q|Feature|,
		lastUpdated => 1031514049
	},

	'29' => {
		message => q|Units|,
		lastUpdated => 1031514049
	},

	'6' => {
		message => q|Edit Product|,
		lastUpdated => 1031514049
	},

    '51 description' => {
        message => q|You may enter a new benefit, or select from one you've already entered.|,
        lastUpdated => 1120337226,
    },

    '52 description' => {
        message => q|If you'd like to add another benefit right away, select "Yes".|,
        lastUpdated => 1120337226,
    },

    '62 description' => {
        message => q|Select a layout for this product.|,
        lastUpdated => 1120332527,
    },

    '10 description' => {
        message => q|The price of this variant.|,
        lastUpdated => 1209496419,
    },

    '7 description' => {
        message => q|An image of this product.|,
        lastUpdated => 1120332527,
    },

    '8 description' => {
        message => q|An image of this product.|,
        lastUpdated => 1120332527,
    },

    '9 description' => {
        message => q|An image of this product.|,
        lastUpdated => 1120332527,
    },

    '13 description' => {
        message => q|The brochure for this product.|,
        lastUpdated => 1120332527,
    },

    '14 description' => {
        message => q|The product, user, or service manual for this product.|,
        lastUpdated => 1120332527,
    },

    '15 description' => {
        message => q|The warranty for this product.|,
        lastUpdated => 1120332527,
    },

	'36' => {
		message => q|Add an accessory.|,
		lastUpdated => 1031514049
	},

	'3' => {
		message => q|Are you certain you wish to delete this feature?|,
		lastUpdated => 1031514049
	},

	'51' => {
		message => q|Benefit|,
		lastUpdated => 1031514049
	},

	'9' => {
		message => q|Product Image 3|,
		lastUpdated => 1031514049
	},

    '23 description' => {
        message => q|You may enter a new feature, or select one you entered for another product in the system.|,
        lastUpdated => 1120335791,
    },

    '24 description' => {
        message => q|If you'd like to add another feature right away, select "Yes".|,
        lastUpdated => 1120335791,
    },

	'58' => {
		message => q|Edit Product Template|,
		lastUpdated => 1031514049
	},

    '20 description' => {
        message => q|Choose from the list of products you've already entered.|,
        lastUpdated => 1120337083,
    },

    '21 description' => {
        message => q|Select "Yes" if you have another related product to add.|,
        lastUpdated => 1120337083,
    },

	'15' => {
		message => q|Warranty|,
		lastUpdated => 1031514049
	},

	'52' => {
		message => q|Add another benefit?|,
		lastUpdated => 1031514049
	},

	'8' => {
		message => q|Product Image 2|,
		lastUpdated => 1031514049
	},

	'60' => {
		message => q|Template|,
		lastUpdated => 1031514049
	},

	'4' => {
		message => q|Are you certain you wish to delete the relationship to this related product?|,
		lastUpdated => 1031514049
	},

	'34' => {
		message => q|Add a feature.|,
		lastUpdated => 1031514049
	},

	'56' => {
		message => q|Add a product template.|,
		lastUpdated => 1031514049
	},

    '17 description' => {
        message => q|Choose from the list of products you've already entered.|,
        lastUpdated => 1120336412,
    },

    '18 description' => {
        message => q|Select "Yes" if you have another accessory to add.|,
        lastUpdated => 1120336412,
    },

	'37' => {
		message => q|Add a related product.|,
		lastUpdated => 1031514049
	},

    '26 description' => {
        message => q|The type of specification. For instance, height, weight,   or color. You may select one you've entered for another product, or type in a new specification.|,
        lastUpdated => 1120336437,
    },

    '27 description' => {
        message => q|The actual specification value. For instance, if you chose height as the Label, then you'd enter a numeric value like "18".|,
        lastUpdated => 1120336120,
    },

    '29 description' => {
        message => q|The unit of measurement for this specification. For instance, if you chose height for your label, perhaps the units would be "meters".|,
        lastUpdated => 1120336120,
    },

    '28 description' => {
        message => q|If you'd like to add another specification, select "Yes".|,
        lastUpdated => 1120336120,
    },

	'19' => {
		message => q|Add Related Product|,
		lastUpdated => 1031514049
	},

	'62' => {
		message => q|Product Template|,
		lastUpdated => 1038864092
	},

	'54' => {
		message => q|Benefits|,
		lastUpdated => 1031514049
	},

	'5' => {
		message => q|Are you certain you wish to delete this specification?|,
		lastUpdated => 1031514049
	},

	'deleteImage' => {
		message => q|Delete Attached File|,
		lastUpdated => 1031514049
	},

	'product asset template variables title' => {
		message => q|Product Asset Template Variables|,
		lastUpdated => 1164841146
	},

	'product asset template variables body' => {
		message => q|Every asset provides a set of variables to most of its
templates based on the internal asset properties.  Some of these variables may
be useful, others may not.|,
		lastUpdated => 1164841201
	},

	'cacheTimeout' => {
		message => q|The amount of time in seconds output from this Asset will be cached.|,
		lastUpdated => 1164841201
	},

	'templateId' => {
		message => q|The ID of the template that will be used to display this Asset.|,
		lastUpdated => 1164841201
	},

	'price' => {
		message => q|The price of this Product.|,
		lastUpdated => 1164841201
	},

	'image1' => {
		message => q|The unique identifier for the storage object for the first image.|,
		lastUpdated => 1164841201
	},

	'image2' => {
		message => q|The unique identifier for the storage object for the second image.|,
		lastUpdated => 1164841201
	},

	'image3' => {
		message => q|The unique identifier for the storage object for the third image.|,
		lastUpdated => 1164841201
	},

	'brochure' => {
		message => q|The unique identifier for the storage object for a product brochure .|,
		lastUpdated => 1164841201
	},

	'manual' => {
		message => q|The unique identifier for the storage object for a product manual.|,
		lastUpdated => 1164841201
	},

	'warranty' => {
		message => q|The unique identifier for the storage object for a product warranty.|,
		lastUpdated => 1164841201
	},

	'weight' => {
		message => q|Weight|,
		context => q|How much something weighs, with no units|,
		lastUpdated => 1209494301,
	},

    'weight description' => {
        message => q|The default weight of the variant.|,
        lastUpdated => 1209494298,
    },

	'quantity' => {
		message => q|Quantity|,
		lastUpdated => 1209494301,
	},

    'quantity description' => {
        message => q|How many units of this variant are available.|,
        lastUpdated => 1209494298,
    },

	'shortdesc' => {
		message => q|Short Description|,
		lastUpdated => 1209494301,
	},

    'shortdesc description' => {
        message => q|The short description will be displayed to the user so they can purchase this variant of your product.  It is limited to 30 characters in length.|,
        lastUpdated => 1215532125,
    },

    'add variant' => {
        message => q|Add Variant.|,
        context => q|Add a variant to this product.  For example, if you sell shirts, this could be a large shirt, a blue shirt, or
        a large blue shirt.|,
        lastUpdated => 1209494298,
    },

	'variant sku' => {
		message => q|SKU|,
		lastUpdated => 1209576604,
	},

	'variant sku description' => {
		message => q|A completely unique identifier for this variant of a product.  Should be the same as used in your inventory software so you can sync them.|,
		lastUpdated => 1209576604,
	},

	'add a variant' => {
		message => q|Add a variant.|,
		lastUpdated => 1210011992,
	},

	'add another variant' => {
		message => q|Add another variant?|,
		lastUpdated => 1210011992,
	},

	'add another variant description' => {
		message => q|If you would like to add another variant right now, select "Yes".|,
		lastUpdated => 1210011992,
	},

	'delete variant confirm' => {
		message => q|Are you certain you wish to delete this variant?|,
		lastUpdated => 1210013857,
	},

	'variants' => {
		message => q|Variants|,
		lastUpdated => 1210019655,
	},

	'addvariant_url' => {
		message => q|A URL to allow new variants to be added to this product.|,
		lastUpdated => 1210029266,
	},

	'addvariant_label' => {
		message => q|The translated label for the add variant link.|,
		lastUpdated => 1210029266,
	},

	'variant_loop' => {
		message => q|A loop containing all the variants for this product.|,
		lastUpdated => 1210029452,
	},

	'variant_id' => {
		message => q|The unique identifier for this variant.|,
		lastUpdated => 1221777106,
	},

	'variant_controls' => {
		message => q|An icon toolbar for editing, deleting, or reordering this variant.|,
		lastUpdated => 1210029452,
	},

	'variant_sku' => {
		message => q|The SKU for this variant.|,
		lastUpdated => 1210029452,
	},

	'variant_title' => {
		message => q|The title, or short description, for this variant.|,
		lastUpdated => 1210029452,
	},

	'variant_price' => {
		message => q|The price for this variant.|,
		lastUpdated => 1210029452,
	},

	'variant_weight' => {
		message => q|The weight for this variant.|,
		lastUpdated => 1210029452,
	},

	'variant_quantity' => {
		message => q|The quantity for this variant.|,
		lastUpdated => 1210029452,
	},

	'add to cart' => {
		message => q|Add to cart|,
		lastUpdated => 1210351464,
		context => q|The label for the add to cart button.|
	},

	'buy_form_header' => {
		message => q|HTML code to start the form for putting variants into a shopping cart.|,
		lastUpdated => 1248282250,
	},

	'buy_form_options' => {
		message => q|A dropdown list of available variants for this product.  Only variants with a quantity greater than zero are listed.|,
		lastUpdated => 1248282203,
	},

	'buy_form_button' => {
		message => q|The submit button for the form, with internationalized text.|,
		lastUpdated => 1210611784,
	},

	'buy_form_footer' => {
		message => q|HTML code to end the form for putting variant into a shopping cart.  |,
		lastUpdated => 1210611784,
	},

	'in_stock' => {
		message => q|A boolean which says whether or not there are available variants of this product for sale|,
		lastUpdated => 1212787075,
	},

	'no_stock_message' => {
		message => q|An internationalized message saying that there are no variants of this product available for sale.|,
		lastUpdated => 1210611784,
	},

	'out of stock' => {
		message => q|Out of stock|,
		lastUpdated => 1210611784,
        context => q|Message displayed to the user when there is no inventory available for sale for a product.|,
	},

	'options' => {
		message => q|Options|,
		lastUpdated => 1211168603,
	},

	'other products' => {
		message => q|Other Products|,
		lastUpdated => 1211168991,
	},

	'default thank you message' => {
		message => q|Thank you for your purchase.|,
		lastUpdated => 0,
		context => q|the default message that will go in the thank you message field|
	},

	'thank you message' => {
		message => q|Thank You Message|,
		lastUpdated => 0,
		context => q|the label for the field where you type in a message thanking the user for their purchase|
	},

	'thank you message help' => {
		message => q|Write a thank you message to your user for buying something from your site.  Be sincere, or they may cancel their purchase and get it from Amazon instead.|,
		lastUpdated => 0,
		context => q|help for default price field|
	},

	'hasAddedToCart' => {
		message => q|A condition indicating that the user has added the product to their cart, so we can display the thank you message.|,
		lastUpdated => 0,
		context => q|template variable|
	},

	'canEdit' => {
		message => q|A boolean that is true if the user can edit this Product.|,
		lastUpdated => 0,
		context => q|template variable|
	},

	'continueShoppingUrl' => {
		message => q|A URL to reset the Product so that the user can continue shopping.|,
		lastUpdated => 0,
		context => q|template variable|
	},

	'isShippingRequired' => {
		message => q|Is shipping required?|,
		lastUpdated => 0,
		context => q|label for the edit sku|
	},

	'isShippingRequired help' => {
		message => q|This determines whether shipping costs will be calculated when the user checks out.|,
		lastUpdated => 0,
		context => q|hover help for isShippingRequired in the edit sku screen|
	},

	'Controls' => {
		message => q|Controls|,
		lastUpdated => 0,
		context => q|A set of links or icons to edit or alter the object.|
	},

};

1;
